pub struct Sam3 {
pub manifest: Manifest,
pub store: Store,
pub cfg: Config,
pub tokenizer: Tokenizer,
pub timing: Timing,
/* private fields */
}Fields
manifest: Manifeststore: Storecfg: Configtokenizer: Tokenizertiming: TimingImplementations
Sourceimpl Sam3
impl Sam3
Sourceimpl Sam3
impl Sam3
Sourcepub fn load(dir: &Path) -> Result<Self, Error>
pub fn load(dir: &Path) -> Result<Self, Error>
Loads the bundle, opens the NPU, loads every kernel and uploads the packed weights.
Sourcepub fn contexts(&self) -> (usize, usize)
pub fn contexts(&self) -> (usize, usize)
Hardware contexts created and evicted so far (evictions happen when another process holds some of the NPU’s contexts).